import Fade from '@material-ui/core/Fade';
import { fade, lighten, darken } from '@material-ui/core/styles/colorManipulator';
import makeStyles$1 from '@material-ui/core/styles/makeStyles';
import CloseIcon from '@material-ui/icons/Close';
import clsx from 'clsx';
import React, { useContext } from 'react';
import { makeStyles } from '@material-ui/core/styles';
import MUITypography from '@material-ui/core/Typography';
import MUIButton from '@material-ui/core/Button';
import MUICard from '@material-ui/core/Card';
export { default as CardActionArea } from '@material-ui/core/CardActionArea';
export { default as CardActions } from '@material-ui/core/CardActions';
export { default as CardContent } from '@material-ui/core/CardContent';
export { default as CardMedia } from '@material-ui/core/CardMedia';
import { makeStyles as makeStyles$2 } from '@material-ui/core';

var bootstrapColors = ["primary", "secondary", "success", "danger", "warning", "info", "light", "dark"];
var bootstrapPalette = function bootstrapPalette(theme) {
  return {
    primary: {
      contrastText: theme.palette.primary.contrastText,
      main: theme.palette.primary.main
    },
    secondary: {
      contrastText: theme.palette.secondary.contrastText,
      main: theme.palette.secondary.main
    },
    success: {
      contrastText: "#fff",
      main: "#5cb85c"
    },
    danger: {
      contrastText: "#fff",
      main: "#d9534f"
    },
    warning: {
      contrastText: "#333",
      main: "#f0ad4e"
    },
    info: {
      contrastText: "#fff",
      main: "#5bc0de"
    },
    light: {
      contrastText: theme.palette.text.secondary,
      main: theme.palette.background.paper
    },
    dark: {
      contrastText: theme.palette.background.paper,
      main: theme.palette.text.primary
    }
  };
};

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var useStyles = /*#__PURE__*/makeStyles(function (theme) {
  var bootstrapColors = {
    primary: {
      color: theme.palette.primary.main
    },
    secondary: {
      color: theme.palette.secondary.main
    },
    success: {
      color: "#218838"
    },
    danger: {
      color: "#c82333"
    },
    warning: {
      color: "#e0a800"
    },
    info: {
      color: "#138496"
    },
    light: {
      color: theme.palette.text.secondary
    },
    dark: {
      color: theme.palette.text.primary
    }
  };

  function getColor(x) {
    return x.color === "inherit" ? {
      color: undefined
    } : bootstrapColors[x.color === undefined ? "dark" : x.color];
  }

  return {
    root: {
      color: function color(x) {
        return getColor(x).color;
      },
      "& a": {
        color: function color(x) {
          return getColor(x).color;
        },
        fontWeight: "bolder",
        textDecoration: "none",
        "&:hover": {
          textDecoration: "underline"
        }
      }
    }
  };
});
var Typography = /*#__PURE__*/React.forwardRef(function BootstrapButton(props, ref) {
  var classes = useStyles(props);

  var otherProps = _objectWithoutPropertiesLoose(props, ["color"]);

  return React.createElement(MUITypography, Object.assign({}, otherProps, {
    classes: classes,
    ref: ref
  }));
});

function bootstrapAlertStyles(color, theme) {
  var palette = bootstrapPalette(theme);
  var clr = color === "light" ? theme.palette.text.secondary : color === "dark" ? theme.palette.text.primary : palette[color].main;
  var borderColor = color === "light" ? theme.palette.divider : fade(lighten(clr, 0.6), 0.8);
  var backgroundColor = color === "light" ? fade(theme.palette.text.secondary, 0.015) : color === "dark" ? theme.palette.text.primary : fade(lighten(clr, 0.8), 0.8);
  var headerColor = color === "dark" ? theme.palette.background.paper : darken(clr, 0.6);
  return {
    borderColor: borderColor,
    backgroundColor: backgroundColor,
    headerColor: headerColor
  };
}

var useStyles$1 = function useStyles(color) {
  return makeStyles$1(function (theme) {
    var _maxWidthXs, _maxWidthSm, _maxWidthMd, _maxWidthLg, _maxWidthXl;

    // @ts-ignore
    var htmlFontSize = theme.typography.htmlFontSize;
    var coef = theme.typography.fontSize / 14;

    var pxToRem = function pxToRem(size) {
      return size / htmlFontSize * coef + "rem";
    };

    var _bootstrapAlertStyles = bootstrapAlertStyles(color, theme),
        borderColor = _bootstrapAlertStyles.borderColor,
        backgroundColor = _bootstrapAlertStyles.backgroundColor,
        headerColor = _bootstrapAlertStyles.headerColor;

    return {
      root: {
        color: headerColor,
        backgroundColor: backgroundColor,
        borderColor: borderColor,
        position: "relative",
        border: "1px solid",
        padding: pxToRem(12) + " " + pxToRem(14),
        paddingRight: "" + pxToRem(28),
        borderRadius: pxToRem(4),
        "& a": {
          color: headerColor
        },
        "& p": {
          margin: 0
        }
      },
      closeIcon: {
        fontSize: pxToRem(18),
        right: 12,
        position: "absolute",
        cursor: "pointer",
        "&:hover": {
          color: "#333"
        }
      },

      /* Styles applied to the root element if `maxWidth="xs"`. */
      maxWidthXs: (_maxWidthXs = {}, _maxWidthXs[theme.breakpoints.up("xs")] = {
        maxWidth: Math.max(theme.breakpoints.values.xs, 444)
      }, _maxWidthXs),

      /* Styles applied to the root element if `maxWidth="sm"`. */
      maxWidthSm: (_maxWidthSm = {}, _maxWidthSm[theme.breakpoints.up("sm")] = {
        maxWidth: theme.breakpoints.values.sm
      }, _maxWidthSm),

      /* Styles applied to the root element if `maxWidth="md"`. */
      maxWidthMd: (_maxWidthMd = {}, _maxWidthMd[theme.breakpoints.up("md")] = {
        maxWidth: theme.breakpoints.values.md
      }, _maxWidthMd),

      /* Styles applied to the root element if `maxWidth="lg"`. */
      maxWidthLg: (_maxWidthLg = {}, _maxWidthLg[theme.breakpoints.up("lg")] = {
        maxWidth: theme.breakpoints.values.lg
      }, _maxWidthLg),

      /* Styles applied to the root element if `maxWidth="xl"`. */
      maxWidthXl: (_maxWidthXl = {}, _maxWidthXl[theme.breakpoints.up("xl")] = {
        maxWidth: theme.breakpoints.values.xl
      }, _maxWidthXl)
    };
  });
};

function Alert(props) {
  var classes = useStyles$1(props.color || "danger")(props);

  var _React$useState = React.useState(true),
      show = _React$useState[0],
      setShow = _React$useState[1];

  React.useEffect(function () {
    if (props.show !== undefined) {
      setShow(props.show);
    }
  }, [props.show]);

  function handleDismiss() {
    setShow(false);

    if (props.onClose !== undefined) {
      props.onClose();
    }
  }

  var maxWidthClass = classes.maxWidthMd;

  switch (props.maxWidth) {
    case "xl":
      maxWidthClass = classes.maxWidthXl;
      break;

    case "lg":
      maxWidthClass = classes.maxWidthLg;
      break;

    case "md":
      maxWidthClass = classes.maxWidthMd;
      break;

    case "sm":
      maxWidthClass = classes.maxWidthSm;
      break;

    case "xs":
      maxWidthClass = classes.maxWidthXs;
      break;
  }

  return React.createElement(Fade, {
    "in": show,
    unmountOnExit: true
  }, React.createElement("div", {
    className: clsx(classes.root, maxWidthClass)
  }, props.dismissible && React.createElement(CloseIcon, {
    onClick: handleDismiss,
    className: classes.closeIcon,
    color: "inherit"
  }), React.createElement(Typography, {
    color: "inherit"
  }, props.children)));
}
var useStylesForHeading = /*#__PURE__*/makeStyles$1({
  icon: {
    marginRight: 10,
    verticalAlign: -6,
    "& > *:first-child": {
      fontSize: 32
    }
  }
});

function Heading(props) {
  var classes = useStylesForHeading();
  return React.createElement(Typography, {
    color: "inherit",
    variant: "h5",
    component: "h2"
  }, props.icon && React.createElement("span", {
    className: classes.icon
  }, props.icon), props.children);
}

Alert.Heading = Heading;

var useStyles$2 = /*#__PURE__*/makeStyles(function (theme) {
  var bootstrapColors = _extends({}, bootstrapPalette(theme));

  function getColor(x) {
    return bootstrapColors[x.color === undefined ? "dark" : x.color];
  } // @ts-ignore


  var htmlFontSize = theme.typography.htmlFontSize;
  var coef = theme.typography.fontSize / 14;

  var pxToRem = function pxToRem(size) {
    return size / htmlFontSize * coef + "rem";
  };

  return {
    root: {
      textTransform: "none",
      boxShadow: "none",
      borderRadius: pxToRem(4),
      padding: function padding(x) {
        return pxToRem(x.size === "large" ? 19 : x.size === "medium" ? 15 : 13) + " " + (x.size === "large" ? 19 : x.size === "medium" ? 15 : 13);
      },
      fontSize: function fontSize(x) {
        return pxToRem(x.size === "large" ? 19 : x.size === "medium" ? 15 : 13);
      },
      lineHeight: "1.5",
      "&.Mui-disabled": {
        opacity: 0.3
      },
      "&.MuiButton-contained": {
        color: function color(x) {
          return getColor(x).contrastText;
        },
        backgroundColor: function backgroundColor(x) {
          return getColor(x).main;
        },
        border: function border(x) {
          return "1px solid " + fade(darken(getColor(x).main, 0.3), 0.3);
        },
        "&:hover": {
          backgroundColor: function backgroundColor(x) {
            return darken(getColor(x).main, 0.25);
          }
        }
      },
      "&.MuiButton-outlined,&.MuiButton-text": {
        color: function color(x) {
          return x.color === "light" ? getColor(x).contrastText : getColor(x).main;
        },
        borderColor: function borderColor(x) {
          return x.color === "light" ? fade(darken(getColor(x).main, 0.3), 0.3) : getColor(x).main;
        },
        "&:hover": {
          backgroundColor: function backgroundColor(x) {
            return x.color === "light" ? fade(lighten(getColor(x).contrastText, 0.2), 0.15) : fade(lighten(getColor(x).main, 0.2), 0.15);
          },
          borderColor: function borderColor(x) {
            return x.color === "light" ? lighten(getColor(x).contrastText, 0.5) : lighten(getColor(x).main, 0.5);
          },
          color: function color(x) {
            return x.color === "light" ? lighten(getColor(x).contrastText, 0.3) : lighten(getColor(x).main, 0.3);
          }
        }
      },
      "&:hover": {
        boxShadow: "none"
      }
    }
  };
});
var Button = /*#__PURE__*/React.forwardRef(function BootstrapButton(props, ref) {
  var classes = useStyles$2(props);

  var otherProps = _objectWithoutPropertiesLoose(props, ["color"]);

  return React.createElement(MUIButton, Object.assign({}, otherProps, {
    classes: classes,
    ref: ref
  }));
});
Button.defaultProps = {
  size: "medium",
  color: "dark"
};

var useStyles$3 = /*#__PURE__*/makeStyles(function (theme) {
  var bootstrapColors = {
    primary: {
      backgroundColor: theme.palette.primary.main,
      color: theme.palette.primary.contrastText
    },
    secondary: {
      backgroundColor: theme.palette.secondary.main,
      color: theme.palette.primary.contrastText
    },
    success: {
      backgroundColor: "#218838",
      color: "#fff"
    },
    danger: {
      backgroundColor: "#c82333",
      color: "#fff"
    },
    warning: {
      backgroundColor: "#e0a800",
      color: "#fff"
    },
    info: {
      backgroundColor: "#138496",
      color: "#fff"
    },
    light: {
      backgroundColor: theme.palette.background["default"],
      color: theme.palette.text.primary
    },
    dark: {
      backgroundColor: fade(theme.palette.text.primary, 0.7),
      color: theme.palette.background["default"]
    }
  };

  function getColor(x) {
    return bootstrapColors[x.color === undefined ? "light" : x.color];
  }

  return {
    root: {
      backgroundColor: function backgroundColor(x) {
        return getColor(x).backgroundColor;
      },
      color: function color(x) {
        return getColor(x).color;
      },
      "& a": {
        color: function color(x) {
          return getColor(x).backgroundColor;
        },
        fontWeight: "bolder",
        textDecoration: "none",
        "&:hover": {
          textDecoration: "underline"
        }
      }
    }
  };
});
var Card = /*#__PURE__*/React.forwardRef(function BootstrapButton(props, ref) {
  var classes = useStyles$3(props);

  var otherProps = _objectWithoutPropertiesLoose(props, ["color"]);

  return React.createElement(MUICard, Object.assign({}, otherProps, {
    classes: classes,
    ref: ref,
    variant: "outlined"
  }));
});
function CardHeader(props) {
  var classes = makeStyles(function (theme) {
    return {
      root: {
        padding: "10px 14px 10px 14px",
        backgroundColor: fade("#000", 0.04),
        borderBottom: "1px solid " + theme.palette.divider
      }
    };
  })();
  return React.createElement("div", {
    className: classes.root
  }, React.createElement(Typography, {
    color: "inherit"
  }, props.children));
}
function CardTitle(props) {
  return React.createElement(Typography, {
    color: "inherit",
    variant: "h5",
    component: "h2"
  }, props.children);
}

var useStyles$4 = /*#__PURE__*/makeStyles$2(function (theme) {
  var palette = bootstrapPalette(theme);
  return {
    root: {
      display: "inline-block",
      padding: ".2em .4em",
      borderRadius: ".35rem",
      color: function color(x) {
        return palette[x.color].contrastText;
      },
      backgroundColor: function backgroundColor(x) {
        return palette[x.color].main;
      }
    }
  };
});
function Label(props) {
  var classes = useStyles$4(props);
  return React.createElement("span", {
    className: clsx(classes.root)
  }, props.children);
}

var PanelContext = /*#__PURE__*/React.createContext("primary");

var useStyles$5 = function useStyles(color) {
  return makeStyles$2(function (theme) {
    var _bootstrapAlertStyles = bootstrapAlertStyles(color, theme),
        borderColor = _bootstrapAlertStyles.borderColor,
        backgroundColor = _bootstrapAlertStyles.backgroundColor,
        headerColor = _bootstrapAlertStyles.headerColor;

    return {
      root: {
        borderRadius: 4,
        border: "1px solid " + borderColor,
        backgroundColor: theme.palette.background.paper
      },
      header: {
        borderBottom: "1px solid " + borderColor,
        backgroundColor: backgroundColor,
        color: headerColor,
        padding: "10px 15px"
      },
      body: {
        padding: 15
      }
    };
  });
};

function Panel(props) {
  var classes = useStyles$5(props.color)();
  return React.createElement("div", {
    className: classes.root
  }, React.createElement(PanelContext.Provider, {
    value: props.color
  }, props.children));
}
function PanelHeader(props) {
  var color = useContext(PanelContext);
  var classes = useStyles$5(color)();
  return React.createElement("div", {
    className: classes.header
  }, props.children);
}
function PanelBody(props) {
  var color = useContext(PanelContext);
  var classes = useStyles$5(color)();
  return React.createElement("div", {
    className: classes.body
  }, props.children);
}

export { Alert, Button, Card, CardHeader, CardTitle, Label, Panel, PanelBody, PanelHeader, Typography, bootstrapColors, bootstrapPalette };
//# sourceMappingURL=material-ui-bootstrap.esm.js.map
